diff mbox

[16/16] qtest/ahci: ncq migration test

Message ID 1434765047-29333-17-git-send-email-jsnow@redhat.com
State New
Headers show

Commit Message

John Snow June 20, 2015, 1:50 a.m. UTC
Signed-off-by: John Snow <jsnow@redhat.com>
---
 tests/ahci-test.c | 15 +++++++++++++--
 1 file changed, 13 insertions(+), 2 deletions(-)

Comments

John Snow June 20, 2015, 2:08 a.m. UTC | #1
On 06/19/2015 09:50 PM, John Snow wrote:
> Signed-off-by: John Snow <jsnow@redhat.com>
> ---
>  tests/ahci-test.c | 15 +++++++++++++--
>  1 file changed, 13 insertions(+), 2 deletions(-)
> 
> diff --git a/tests/ahci-test.c b/tests/ahci-test.c
> index 941e0dd..206e6bb 100644
> --- a/tests/ahci-test.c
> +++ b/tests/ahci-test.c
> @@ -1140,9 +1140,9 @@ static void test_migrate_sanity(void)
>  }
>  
>  /**
> - * DMA Migration test: Write a pattern, migrate, then read.
> + * Simple migration test: Write a pattern, migrate, then read.
>   */
> -static void test_migrate_dma(void)
> +static void ahci_migrate_simple(uint8_t cmd_read, uint8_t cmd_write)
>  {
>      AHCIQState *src, *dst;
>      uint8_t px;
> @@ -1183,6 +1183,16 @@ static void test_migrate_dma(void)
>      g_free(tx);
>  }
>  

This is what I get for staying up so late...

It would help if I actually used the parameters I created to use the
right command.

Fixed offline in a v2, will send out after other comments if any.

> +static void test_migrate_dma(void)
> +{
> +    ahci_migrate_simple(CMD_READ_DMA, CMD_WRITE_DMA);
> +}
> +
> +static void test_migrate_ncq(void)
> +{
> +    ahci_migrate_simple(READ_FPDMA_QUEUED, WRITE_FPDMA_QUEUED);
> +}
> +
>  /**
>   * DMA Error Test
>   *
> @@ -1665,6 +1675,7 @@ int main(int argc, char **argv)
>      qtest_add_func("/ahci/reset", test_reset);
>  
>      qtest_add_func("/ahci/io/ncq/simple", test_ncq_simple);
> +    qtest_add_func("/ahci/migrate/ncq/simple", test_migrate_ncq);
>  
>      ret = g_test_run();
>  
>
diff mbox

Patch

diff --git a/tests/ahci-test.c b/tests/ahci-test.c
index 941e0dd..206e6bb 100644
--- a/tests/ahci-test.c
+++ b/tests/ahci-test.c
@@ -1140,9 +1140,9 @@  static void test_migrate_sanity(void)
 }
 
 /**
  * DMA Migration test: Write a pattern, migrate, then read.
  */
-static void test_migrate_dma(void)
+static void ahci_migrate_simple(uint8_t cmd_read, uint8_t cmd_write)
 {
     AHCIQState *src, *dst;
     uint8_t px;
@@ -1183,6 +1183,16 @@  static void test_migrate_dma(void)
     g_free(tx);
 }
 
+static void test_migrate_dma(void)
+{
+    ahci_migrate_simple(CMD_READ_DMA, CMD_WRITE_DMA);
+}
+
+static void test_migrate_ncq(void)
+{
+    ahci_migrate_simple(READ_FPDMA_QUEUED, WRITE_FPDMA_QUEUED);
+}
+
 /**
  * DMA Error Test
  *
@@ -1665,6 +1675,7 @@  int main(int argc, char **argv)
     qtest_add_func("/ahci/reset", test_reset);
 
     qtest_add_func("/ahci/io/ncq/simple", test_ncq_simple);
+    qtest_add_func("/ahci/migrate/ncq/simple", test_migrate_ncq);
 
     ret = g_test_run();
@@ -1140,9 +1140,9 @@  static void test_migrate_sanity(void)
 
 /**
- * DMA Migration test: Write a pattern, migrate, then read.
+ * Simple migration test: Write a pattern, migrate, then read.
  */